sfs.fd.source
=============

.. automodule:: sfs.fd.source

   
   
   .. rubric:: Functions

   .. autosummary::
   
      line
      line_bandlimited
      line_dipole
      line_dirichlet_edge
      line_velocity
      plane
      plane_averaged_intensity
      plane_velocity
      point
      point_averaged_intensity
      point_dipole
      point_image_sources
      point_modal
      point_modal_velocity
      point_velocity
      pulsating_sphere
      pulsating_sphere_velocity
   
   

   
   
   

   
   
   